package POE::Component::IKC;
# $Id: IKC.pm 168 2006-11-16 19:57:48Z fil $

use strict;
use vars qw( $VERSION );
$VERSION="0.1903";

# Force CPAN to see this

1;

__END__

$Log$
Revision 1.1.2.2  2006/11/01 18:30:53  fil
Moved to version 0.1902

Revision 1.1.2.1  2006/10/03 22:52:31  fil
Fixed memory leak
Added IKC.pm

Revision 1.1  2006/08/29 22:09:16  fil
Added forgoten bits

